@@ -77,7 +77,6 @@ where
 import Data.List ((!!))
 import qualified Data.Vector as V
 import GHC.Exts (IsList (..))
-import GHC.Show (Show (..))
 import GHC.TypeLits
 import qualified NumHask.Array.Dynamic as D
 import qualified NumHask.Array.Fixed as F
@@ -148,19 +147,7 @@ instance
 
 type instance Actor (Array s a) = a
 
-instance
-  ( HasShape s,
-    P.Distributive a,
-    CommutativeRing a,
-    Semiring a,
-    H.Container H.Vector a,
-    Num (H.Vector a),
-    Num a
-  ) =>
-  Hilbert (Array s a)
-  where
-  (<.>) (Array a) (Array b) = H.sumElements $ H.liftMatrix2 (Prelude.*) a b
-  {-# INLINE (<.>) #-}
+-- (<.>) (Array a) (Array b) = H.sumElements $ H.liftMatrix2 (Prelude.*) a b
 
 instance
   ( HasShape s,
